% This is a second order electromagnetically actuated mass spring
% damper system, described in
%
%  R. H. Miller, I. Kolmanovsky, E. G. Gilbert, and P. D. Washabaugh.
%     Control of constrained nonlinear systems: a case study.  IEEE
%     Control Systems Magazine, 20(1):23--32, 2000. 

function jac = springpart(x,t)

global uk wk

u = uk;

alpha = 4.5e-5;
gamma = 1.99;
c = 0.6590;
k = 38.94;
d0 = .0102;
m = 1.54;

jac = zeros(2,3);

jac(1,2) = 1;
jac(2,1) = -(k/m) + (alpha/m)*gamma*(u/(d0-x(1))^(gamma+1));
jac(2,2) = -(c/m);
jac(2,3) = (alpha/m)*(1/(d0-x(1))^gamma);

if (x(1) > .0101)
  jac(2,1) = -(k/m);
  jac(2,3) = (alpha/m)*(1/(d0-.0101)^gamma);
end

